function useEchart() {
  const echartList = ref([])

  const echartRemove = () => {
    echartList.value.forEach(el => {
      if (el && el.dispose) {
        el.dispose()
      }
    })
    echartList.value = []
  }

  const start = (options) => {
    if (options) {
      setTimeout(() => {
        loadFile(
          document,
          {
            src: './js/plugin/echart.min.js',
            tag: 'script',
            type: 'text/javascript',
            defer: 'defer'
          },
          () => {
            loadFile(
              document,
              {
                src: './js/plugin/ecStat.min.js',
                tag: 'script',
                type: 'text/javascript',
                defer: 'defer'
              },
              () => {
                const isDark = document.querySelector('html').getAttribute('dark-mode') === 'true'
                echarts.registerTransform(ecStat.transform.regression)

                Object.values(options).map((item) => {
                  let dom = document.querySelector(`#${item.id}`)
                  if (dom) {
                    const type = item.option.series[0].type
                    const title = item.option.title ? item.option.title.text || '' : ''
                    let yValueName = ''

                    const isScatter = item.option.series && item.option.series.length === 2
                    const seriesObjSecond = item.option.series ? item.option.series[1] : {}
                    item.option.yAxis = item.option && item.option.yAxis ? item.option.yAxis[0] : {}
                    item.option.yAxis.offset = 0
                    if (isScatter) {
                      item.option.yAxis.nameTextStyle = {}
                      item.option.yAxis.nameTextStyle.align = 'left'
                      item.option.yAxis.nameTextStyle.padding = [ 0, 0, 0, -34 ]
                    } else {
                      yValueName = item.option.yAxis.name
                      delete item.option.yAxis.name
                    }

                    dom.outerHTML = `<div class="en-echart">${!!title ?
                      `<div class="en-echart-title droidSerif-bold">${item.option.title.text}</div>` : ''}${!!yValueName ? `<div class="en-echart-yname">${yValueName}</div>` : ''}<div class="" style="width: 100%; height: ${type === 'pie' ? 5 : 6.29333}rem; margin: 0 auto;" id="${item.id}"></div></div>`
                    let dom2 = document.querySelector(`#${item.id}`)
                    let chart = echarts.init(dom2, null, {
                      renderer: 'svg',
                      useDirtyRect: false
                    })

                    echartList.value.push(chart)

                    chart.on('finished', function () {
                      changeContentHtmlHeight()
                    })

                    delete item.option.title
                    if (isScatter) {   // 是指数回归
                      renderScatter(chart, item)
                    } else {    //  是其他图形
                      const areaStyle = item.option.series[0].areaStyle
                      if (areaStyle) {
                        item.option.xAxis = item.option.xAxis[0]
                      }
                      const pie = type === 'pie' ? {
                        avoidLabelOverlap: false,
                        label: {
                          normal:
                            {
                              position: 'inner',
                              formatter: '{d}%',
                              fontWeight: 'normal',
                              fontFamily: 'DroidSerif',
                              fontSize: `${10/37.5}rem`,
                              color: '#fff'
                            }
                        },
                        labelLine: {
                          show: false
                        },
                        tooltip: {
                          trigger: 'item',
                          formatter: '{b}:{c} ({d}%)'
                        }
                      } : {}
                      chart.setOption({
                        ...item.option,
                        backgroundColor: isDark ? '#161827' : '#fff',
                        grid: {
                          containLabel: true,
                          left: '0%',
                          right: '5%',
                          top: type === 'pie' ? '0%' : '6%',
                          bottom: '5%',
                        },
                        dataset: [
                          {
                            source: item.option.dataset ? item.option.dataset[0].source : ''
                          },
                          {
                            transform: {
                              type: 'ecStat:regression',
                              config: {
                                method: 'exponential'
                              }
                            }
                          }
                        ],
                        legend: type === 'pie' ? {
                          left: -5,
                          borderRadius: 0,
                          orient: 'vertical',
                          top: 'center'
                        } : undefined,
                        series: [
                          {
                            ...item.option.series[0],
                            radius: [ '40%', '90%' ],
                            itemStyle: type === 'line' ? {
                              'color': '#B71D26',
                              'lineStyle': {
                                'color': '#B71D26'
                              }
                            } : undefined,
                            center: type === 'pie' ? [ '74%%', '50%' ] : null,
                            symbol: type === 'line' ? 'circle' : type === 'scatter' ? seriesObjSecond.symbol : '',
                            symbolSize: type === 'line' ? '7' : type === 'scatter' ? seriesObjSecond.symbolSize : '',
                            areaStyle: type === 'line' && !!areaStyle ? {
                              color: {
                                type: 'linear',
                                x: 0,
                                y: 0,
                                x2: 0,
                                y2: 1,
                                colorStops: [
                                  {
                                    offset: 0,
                                    color: 'rgba(183,29,38,0.50)' // 0% 处的颜色
                                  },
                                  {
                                    offset: 1,
                                    color: 'rgba(183,29,38,0.00)' // 100% 处的颜色
                                  }
                                ],
                                global: false // 缺省为 false
                              }
                            } : undefined,
                            ...pie
                          }
                        ]
                      })
                    }
                  }
                })
              }
            )
          }
        )
      }, 100)
    }
  }

  const renderScatter = (chart, item) => {
    const isDark = document.querySelector('html').getAttribute('dark-mode') === 'true'
    chart.setOption({
      ...item.option,
      backgroundColor: isDark ? '#161827' : '#fff',
      grid: {
        containLabel: true,
        left: '0%',
        top: '15%',
        bottom: '10%',
      },
      dataset: item.option.dataset,
      series: [
        {
          ...item.option.series[0]
        },
        {
          ...item.option.series[1],
          labelLayout: { dx: -60, dy: -10 }
        }
      ]
    })

  }

  return {
    start,
    echartRemove
  }
}
