function useVideo(netstutas, networkSwitch, audioState, details, audioPlayNum) {
  const { directions, start: startScroll } = useScroll()

  const videoFixed = ref(false)

  const videoPreview = ref([])
  const defaultVideoPreview = ref([])
  const enPlayerVideoLen = ref(0)

  const videoLoadNum = ref(0)
  const videoLoaded = ref(false)

  const videoState = reactive({
    currentVideo: {}
  })

  watch(videoLoadNum, (val) => {
    if (val === defaultVideoPreview.value.length) {
      videoLoaded.value = true
    }
  })

  watch(audioState, (val) => {
    if (val) {
      defaultVideoPreview.value.forEach(item => {
        if (item.dp) {
          if (videoFixed.value) {
            item.dp.pause()
            item.player.events.layerDom.toggleCommonLayer(item.player.template.$miniLayer, true)

            setTimeout(() => {
              item.dp.pause()
              item.player.events.layerDom.toggleCommonLayer(item.player.template.$miniLayer, true)
            }, 200)
          } else {
            item.dp.pause()
            item.player.events.layerDom.tooglePlayerBottom(false)
            item.player.events.layerDom.toggleLayerPause(true)
            item.player.events.layerDom.toggleBottomPlayState(false)

            setTimeout(() => {
              item.player.events.layerDom.tooglePlayerBottom(false)
              item.player.events.layerDom.toggleLayerPause(true)
              item.player.events.layerDom.toggleBottomPlayState(false)
            }, 200)
          }
        }
      })
    }
  })

  const haeVideo = computed(() => Object.keys(videoState.currentVideo).length > 0)   // 是否有视频的具体数据

  // 每个富文本里面的video加入到数组中
  const addVideoList = (option) => {
    videoPreview.value.push(option.id)
    defaultVideoPreview.value.push({
      id: option.id,
      url: option.src,
      poster: option.poster,
      originId: option.originId,
      rect: {
        top: 0, width: 0, height: 0
      },
      el: null,
      elPatent: null,
      player: null,
      dp: null
    })
  }

  const findVideo = (id) => {
    return defaultVideoPreview.value.find((el) => el.id === id)
  }

  const removeVideoModal = () => {
    if (haeVideo.value && videoState.currentVideo.player && videoFixed.value) {
      videoFixed.value = false

      videoState.currentVideo.dp.pause()
      videoState.currentVideo.player.events.layerDom.toggleFixedLayer(false)

      videoPreview.value = []

      videoState.currentVideo = {}
    }
  }

  // 关闭固定视频弹窗
  const closeVideoModal = (e) => {
    if (e) { e.stopPropagation() }
    if (haeVideo.value && videoState.currentVideo.player && videoFixed.value) {
      videoFixed.value = false
      videoState.currentVideo.player.events.layerDom.toggleFixedLayer(false)
      videoState.currentVideo.player.events.layerDom.toggleCommonLayer(videoState.currentVideo.player.template.$miniClose, false)
      videoState.currentVideo.player.events.layerDom.toggleCommonLayer(videoState.currentVideo.player.template.$miniLayer, false)

      if (
        (videoState.currentVideo.player.template.$video.currentTime >= videoState.currentVideo.player.template.$video.duration)
        && videoState.currentVideo.player.template.$video.currentTime > 0
      ) {
        videoState.currentVideo.player.events.clearSetTimeOut()
        videoState.currentVideo.player.events.playerEnd = true
        videoState.currentVideo.player.events.layerDom.toggleBottomPlayState(false)
        if (videoState.currentVideo.dp.fullscreenService.getIsFullScreen()) {
          videoState.currentVideo.dp.fullscreenService.cancelFullScreen()
          videoState.currentVideo.player.template.$bottomFullScreen.setAttribute('src', './image/player/fullScreen.svg')
        }
        videoState.currentVideo.player.events.layerDom.toggleCommonLayer(videoState.currentVideo.player.template.$replay, true)
        videoState.currentVideo.player.events.layerDom.tooglePlayerBottom(false)
      } else {
        if (videoState.currentVideo.dp.getStatus() !== 'playing') {
          videoState.currentVideo.player.events.layerDom.toggleLayerPause(true)
        } else if (videoState.currentVideo.dp.getStatus() === 'playing') {
          videoState.currentVideo.player.events.layerDom.toggleBottomPlayState(true)
        }
      }

      videoPreview.value = defaultVideoPreview.value
      .filter((item) => {
        return item.elPatent.getBoundingClientRect().top + item.rect.height > 0
      })
      .map((item) => item.id)

      videoState.currentVideo = {}
    }
  }

  watch(audioPlayNum, (val) => {
    if (val) {
      closeVideoModal()

      defaultVideoPreview.value.forEach(item => {
        if (item.dp) {
          item.dp.pause()
          item.player.events.layerDom.tooglePlayerBottom(false)
          item.player.events.layerDom.toggleLayerPause(true)
          item.player.events.layerDom.toggleBottomPlayState(false)

          setTimeout(() => {
            item.player.events.layerDom.tooglePlayerBottom(false)
            item.player.events.layerDom.toggleLayerPause(true)
            item.player.events.layerDom.toggleBottomPlayState(false)
          }, 200)
        }
      })
    }
  }, { deep: true })

  // 处理滚动视频固定逻辑
  const handleScroll = () => {
    const footerHeight = document.querySelector('.footer')
      ? document.querySelector('.footer').getBoundingClientRect().height : 0
    if (!defaultVideoPreview.value.length) return
    if (videoFixed.value && videoState.currentVideo.player.events.dragFixInt.dataState.dragIng) return
    // 下
    if (directions.bottom) {
      // 找到正在播放且要消失在屏幕且没有固定的的视频item
      if (!videoFixed.value && !haeVideo.value) {
        const hiddenVdeoId = videoPreview.value.find((item) => {
          const record = findVideo(item)
          return (Math.abs(record.elPatent.getBoundingClientRect().top) - record.rect.height) >= 0 &&
            record.elPatent.getBoundingClientRect().top < 0 &&
            record.dp.getStatus() === 'playing'
        })
        if (hiddenVdeoId) {
          videoState.currentVideo = {}
          videoState.currentVideo = findVideo(hiddenVdeoId)
        }
      }
      // 当前要固定的视频列已找到并且没有固定的视频把他固定住
      if (haeVideo.value && !videoFixed.value) {

        if (videoState.currentVideo.dp && videoState.currentVideo.dp.getStatus() === 'playing') {   // 只有播放状态滚动过时才展示固定小窗
          videoFixed.value = true
          videoState.currentVideo.player.events.layerDom.toggleFixedLayer(true)
        } else {
          closeVideoModal()
        }
      } else {
        // 当前固定的视频并且滑动到视频列出现在视野中消失
        const hiddenVdeoId = defaultVideoPreview.value.find((item) => {
          const viewPortHeight = window.innerHeight || document.documentElement.clientHeight
                                 || document.body.clientHeight
          const offsetTop = item.elPatent.offsetTop
          const scrollTop = document.querySelector('body #app').scrollTop
          return offsetTop - scrollTop < (viewPortHeight - footerHeight) && videoState.currentVideo.id === item.id
        })
        if (hiddenVdeoId && videoState.currentVideo.topFixed) {
          closeVideoModal()
        }
      }
    } else { // 上
      // 有固定的视频
      if (videoFixed.value) {
        const currentVideos = defaultVideoPreview.value.find((item) => {
          return item.elPatent.getBoundingClientRect().top + item.rect.height > 0 && videoState.currentVideo.id === item.id
        })

        if (currentVideos) {
          const viewPortHeight = window.innerHeight || document.documentElement.clientHeight
                                 || document.body.clientHeight
          const offsetTop = currentVideos.elPatent.offsetTop
          const scrollTop = document.querySelector('body #app').scrollTop
          if (offsetTop - scrollTop > (viewPortHeight - footerHeight)) {
          } else {
            closeVideoModal()
          }
        }
      } else {
        const currentVideos = defaultVideoPreview.value.find((item) => {
          return item.elPatent.getBoundingClientRect().top + item.rect.height > 0
        })

        if (currentVideos) {
          videoPreview.value = defaultVideoPreview.value.filter((item) => {
            return item.elPatent.getBoundingClientRect().top + item.rect.height > 0
          }).map(item => item.id)

          const needFixVideo = defaultVideoPreview.value.find((item, index) => {
            const viewPortHeight = window.innerHeight || document.documentElement.clientHeight
                                   || document.body.clientHeight
            const offsetTop = item.elPatent.offsetTop
            const scrollTop = document.querySelector('body #app').scrollTop
            return (offsetTop - scrollTop) > (viewPortHeight - footerHeight) && item.dp && item.dp.getStatus() === 'playing'
          })

          if (needFixVideo) {
            videoState.currentVideo = $.extend(true, {}, findVideo(needFixVideo.id))
            if (videoState.currentVideo.dp) {
              videoFixed.value = true
              videoState.currentVideo.topFixed = true
              videoState.currentVideo.player.events.layerDom.toggleFixedLayer(true)
            }
          }
        }
      }
    }
  }

  // 监听客户端网络状况以及是否点过继续状态
  watch([ () => networkSwitch.value, () => netstutas.value, () => enPlayerVideoLen.value ], ([ hasSwitch, status, videoLen ]) => {
    if (videoLen === 0) {
      return
    }
    if (status === 0) {
      closeVideoModal()
      showAllErrorModal()
      return
    }
    if (hasSwitch == 2) {
      if (status === 1) {
        // 把所有错误、继续状态清空
        clearAllStatuModal()
      } else {
        // 把所以继续状态展示
        // 若果点击当前播放器继续按钮，当前视频要播放、其他的要暂停
        closeVideoModal()
        showNetworkModal()
      }
    } else {
      // 把所有错误、继续状态清空
      clearAllStatuModal()
    }
  }, {
    deep: true
  })

  // 所有视频展示不是wifi确定页面
  const showNetworkModal = () => {
    defaultVideoPreview.value.forEach((el) => {
      if (el.dp) {
        el.dp.pause()
      }
      el.player.events.layerDom.toggleCommonLayer(el.player.template.$network, true)
      el.player.events.layerDom.clearOthersLayer('network')
    })
  }

  // 所有视频展示错误页面
  const showAllErrorModal = () => {
    defaultVideoPreview.value.forEach((el) => {
      if (el.dp) {
        el.dp.pause()

        el.player.events.layerDom.toggleCommonLayer(el.player.template.$error, true)
        el.player.events.layerDom.clearOthersLayer('error')

        pointErrorFun('network connection failed')
      }
    })
  }

  // 所有视频去除不是wifi确定页面、错误页面
  const clearAllStatuModal = () => {
    defaultVideoPreview.value.forEach((el) => {
      if (el.dp) {
        el.player.events.layerDom.clearOthersLayer('all')
      }
    })
  }

  const pointErrorFun = (error) => {
    const record = deepCopy(details.value)
    record.mainChannel = record.channelList ? record.channelList[0] : {}
    const secondChannel = record.channelList ? record.channelList[1] : {}
    record.secondId = secondChannel ? secondChannel.channelId || '' : ''
    record.errorVideo = error

    playeErrorPoint(pointData(record), !!record.traceId)
  }

  // 初始换每个video标签，转化成 artplayer 播放器
  const startVideo = () => {
    startScroll(handleScroll)
    const videoList = document.querySelectorAll('.content .video-player')
    if (videoList.length) {
      $('.content .video-player').each((index) => {
        const videoItem = videoList[index]
        const width = videoItem.getBoundingClientRect().width
        const domId = videoItem.getAttribute('id')
        const id = videoItem.getAttribute('data-id')
        const originWidth = videoItem.getAttribute('data-width') || 0
        const originHeight = videoItem.getAttribute('data-height') || 0
        const record = defaultVideoPreview.value.find((el) => el.id === id)

        let height = isNumber(Number(originWidth)) ? isNaN(Number(originWidth)) || Number(originWidth) === 0
          ? 0
          : Number(width) * Number(originHeight) / Number(originWidth) : 0

        const isGiveWidth = !!height

        videoItem.setAttribute('data-height', `${height}px`)
        videoItem.style.height = `${height}px`
        videoItem.parentNode.style.width = `100%`
        videoItem.parentNode.style.height = `${height}px`

        videoLoadNum.value += 1

        changeContentHtmlHeight()

        const player = new videoEnPlayer({
          config: {
            key: index,
            record,
            isGiveWidth,
            width,
            height
          },
          callBackFun: {
            ready: (playerWdith, playerHieght, callBack) => {
              if (isGiveWidth) return
              const newHeight = !!playerWdith && !!playerHieght ? Number(width) * Number(playerHieght) / Number(playerWdith) : 300
              videoItem.setAttribute('data-height', `${newHeight}px`)
              videoItem.style.height = `${newHeight}px`
              videoItem.parentNode.style.width = `100%`
              videoItem.parentNode.style.height = `${newHeight}px`
              callBack(newHeight)
              changeContentHtmlHeight()
            },
            play: () => {
              const _editor36 = document.querySelectorAll('.preview-audio-player')
              const coverAudioList = document.querySelectorAll('.preview-audio-player-cover')
              _editor36.forEach((item, _) => {
                const audioStylePlay = item.querySelector('.audio-play-icon')
                const audioStylePause = item.querySelector('.audio-pause-icon')

                const item_audio = item.querySelector('[class^="audio-block"]')
                if (item_audio) {
                  item_audio.pause()
                  audioStylePause.style.display = 'none'
                  audioStylePlay.style.display = 'block'
                }
              })
              coverAudioList.forEach((item, _) => {
                const audioStylePlay = item.querySelector('.audio-play-icon')
                const audioStylePause = item.querySelector('.audio-pause-icon')

                const item_audio = item.querySelector('[class^="audio-block"]')
                if (item_audio) {
                  item_audio.pause()
                  audioStylePause.style.display = 'none'
                  audioStylePlay.style.display = 'block'
                }
              })
            },
            pointError: () => {
              pointErrorFun('video url error')
            },
            closeFixModal: (id) => {
               if(id) {
                 const record = defaultVideoPreview.value.find(item => item.id === id)

                 if (record && record.dp) {
                   record.dp.pause()
                 }
               }

              closeVideoModal()
            },
            pauseOhterDp: (currentId) => {
              defaultVideoPreview.value = defaultVideoPreview.value.map((item) => {
                if (item.id !== currentId) {
                  item.dp.pause()
                  item.player.events.layerDom.toggleLayerPause(true)
                  item.player.events.layerDom.tooglePlayerBottom(false)
                }
                return item
              })
            },
            continueNetwork: () => {
              networkSwitch.value = 1
            }
          }
        })

        defaultVideoPreview.value = defaultVideoPreview.value.map((item) => {
          if (item.id === id) {
            enPlayerVideoLen.value += 1
            item.index = index
            item.rect.width = width
            item.rect.height = height
            item.el = videoItem
            item.elPatent = videoItem.parentNode
            item.dp = player.player
            item.player = player
            item.domId = domId
          }
          return item
        })
      })

      addEventListenerWrap(document.querySelector('.preview-video-modal'), 'click', () => {
        videoUtil.toggle()
      })

      addEventListenerWrap(document.querySelector('.preview-video-modal .close'), 'click', (e) => {
        closeVideoModal(e)
      })

    }
  }

  // 外层初始调用
  const initVideo = () => {
    if (defaultVideoPreview.value.length > 0) {
      loadFile(document, {
        src: './js/plugin/aliPlayer.min.js', tag: 'script', type: 'text/javascript', defer: 'defer'
      }, () => {
        startVideo()
      })
    }
  }

  // 销毁每个视频 artplayer 播放器
  const removeDpVideo = () => {
    defaultVideoPreview.value = defaultVideoPreview.value.map((el) => {
      if (el.player) el.player.destroy()
      el.dp = null
      el.player = null
      return el
    })

    removeVideoModal()

    videoState.currentVideo = {}
    videoPreview.value = []
    defaultVideoPreview.value = []
  }

  return {
    initVideo, removeDpVideo, addVideoList, videoPreview, videoLoaded
  }
}
