dayjs.extend(dayjs_plugin_localizedFormat)
dayjs.extend(dayjs_plugin_relativeTime)

const { toRef } = Vue
const nowTime = dayjs()

const { onMounted, toRefs, nextTick, watchEffect } = Vue

function timeFromNow(str) {
  if (!str) return ''
  if (dayjs().diff(str, 'minute') < 1) return 'just now'
  if (dayjs().diff(str, 'minute') >= 1 && dayjs().diff(str, 'minute') < 2) return `1 min ago`
  if (dayjs().diff(str, 'minute') >= 2 && dayjs().diff(str, 'minute') < 60) return `${dayjs().diff(str, 'minute')} mins ago`
  if (dayjs().diff(str, 'hour') >= 1 && dayjs().diff(str, 'hour') < 2) return `${dayjs().diff(str, 'hour')} hour ago`
  if (dayjs().diff(str, 'hour') >= 2 && dayjs().diff(str, 'hour') < 24) return `${dayjs().diff(str, 'hour')} hours ago`
  if (dayjs().diff(str, 'day') >= 1 && dayjs().diff(str, 'day') < 2) return `1 day ago`

  return ''
}

function getChinaTimeUix(publishTime) {
  const bjZone = 8//中国时区
  const timezone = new Date().getTimezoneOffset() / 60 * -1//获取时区; //目标时区时间，东八区   东时区正数 西市区负数
  const nowDate = dayjs(publishTime).valueOf() // 当前时间距 1970 年 1 月 1 日午夜（GMT 时间）之间的毫秒数
  const targetDate = new Date(nowDate - (bjZone - timezone) * 60 * 60 * 1000)
  return targetDate
}

const app = Vue.createApp({
  setup() {
    const time = ref('')
    const loginTime = ref()
    const showAction = ref(false)
    const nextArticleData = ref([])
    const subjectList = ref([])
    const channelList = ref([])
    const suggestedList = ref([])

    const optionList = ref([])

    const canSeeBtnOne = ref(true)
    const canSeeBtnTwo = ref(true)

    const networkStatus = ref(1) // 0 无网络 1 wifi 2，3，4，5 无wifi状态
    const networkSwitch = ref(2) // 1 允许 2 不允许
    const audioState = ref(0) // 外部音频点击暂停次数

    const flagSub = ref(false)
    const articNumber = ref(0)
    const recommondClickActive = ref(false)

    const state = reactive({
      voteId: null,
      firstObject: {},
      sourcePage: '2',
      darkMode: 'light',
      environment: 'uat',
      actionImage: 0,
      isRecommond: false,
      firstSubRes: false,
      nextNodata: true,
      hasNext: true,
      nextInit: false,
      nextLoading: false,
      nextClick: false,
      showShare: false,
      appHeader: {
        ...window.config.VUE_BASE_HEADER,
        system: judgTerminal() === 1 ? 'Android' : 'ios'
      },
      nextParams: {
        topicId: undefined,
        channelId: undefined
      },
      initialRes: {},
      originDataSource: {},
      details: {
        author: [],
        voteInfo: {},
        endTimePoint: '',
        yes: {},
        no: {},
        options: []
      },
      voteState: {
        status: 0,
        optionId: 0
      },
      nextPageInfo: {
        pageNum: 1,
        pageSize: 20
      },
      curIndex: 0,
      bcIndex: 0,
      Doing: false,
      isLogined: 0,   // 0 未登录  1 已登录
      isSub: false,
      isSubClose: false,
      seeEmailSub: false,
      strategy: {},
      emailVal: '',
      deviceId: '',
      userId: '',
      aboutUserName: '',
      agreementURL: '',
      recomList: []
    })

    const {
      initEditorStr,
      refreshEditorStr
    } = useEditorContent(toRef(state, 'details'), networkStatus, networkSwitch, audioState)

    onMounted(() => {
      if (slow) return
      if (!slow) fast = true
      if (window.config.VUE_BASE_NODE === 'dev') {
        loadFile(document, {
          src: './js/mock/mock.min.js',
          tag: 'script',
          type: 'text/javascript',
          defer: 'defer'
        }, () => {
          loadFile(document, {
            src: './js/mock/index.js',
            tag: 'script',
            type: 'text/javascript',
            defer: 'defer'
          }, () => {
            // state.darkMode = 'dark'
            // document.querySelector('html').setAttribute('dark-mode', true)
            state.environment = window.config.VUE_BASE_HEADER.environment
            clearInterval(time.value)
            console.log(state.environment)
            state.deviceId = state.appHeader.device_id
            initData({}, 30012244962)
            state.nextParams = {
              topicId: undefined,
              channelId: '3'
            }
          })
        })
      } else {
        time.value = setInterval(() => {
          const config = window.config.VUE_CONTENT_CONFIG
          try {
            const data = typeof config === 'object' ? config : JSON.parse(config)
            if (data.dataJson) {
              const dataJson = typeof data.dataJson === 'object' ? data.dataJson : JSON.parse(data.dataJson)
              state.sourcePage = dataJson.sourcePage
              state.isRecommond = dataJson.isRecommend == '1'
              clearInterval(time.value)
              sendNative('jsCall_getAppPublicInfo', {}, (header) => {
                const headerObj = typeof header === 'object' ? header : JSON.parse(header)
                state.appHeader = deepCopy(headerObj)
                state.darkMode = state.appHeader.darkMode
                if (state.darkMode === 'dark') {
                  document.querySelector('html').setAttribute('dark-mode', true)
                }
                state.deviceId = state.appHeader.device_id
                state.userId = state.appHeader.userId

                state.agreementURL = state.appHeader.agreementURL
                networkStatus.value = state.appHeader.networkStatus
                state.environment = state.appHeader.environment

                if (state.environment === 'uat' || state.environment === 'sit') {
                  new VConsole()
                }


                state.nextParams.compId = dataJson.compId
                state.nextParams.topicId = dataJson.topicId
                state.nextParams.channelId = dataJson.channelId
                state.nextParams.channelId = dataJson.channelId

                const netError = dataJson.netError

                if (netError == 0) {
                  let initialRes = dataJson.responseMap
                  initialRes = typeof initialRes === 'object' ? initialRes : JSON.parse(initialRes)
                  initData(initialRes, dataJson.contentId)
                } else {
                  errorResponse()
                  errorBlock('./image/no_net.png', 'Please check your network connection and try again!')
                }
              })
            }
          } catch (e) {}
        }, 20)
      }
    })

    //点击协议提示字跳转到协议页面
    const inptClick = () => {
      try {
        sendNative(
          'jsCall_appInnerLinkMethod',
          {
            appInnerLink: `peopledailyen://rmrb.app/openwith?type=h5&url=${state.agreementURL}&skipType=3`
          }
        )
      } catch (e) {}
    }
    // 消除邮件订阅部分
    const closeEmailSub = () => {
      state.isSubClose = true
      if (window.config.VUE_BASE_NODE === 'dev') {
      } else {
        try {
          sendNative(
            'jsCall_currentPageOperate',
            {
              operateType: '5'
            }
          )
        } catch (e) {}
      }
    }
    // 提交邮件订阅按钮
    const emailSubmit = () => {
      if (!flagSub.value) {
        flagSub.value = true
        const reg = /^[A-Za-z0-9\u4e00-\u9fa5]+@[a-zA-Z0-9_-]+(.[a-zA-Z0-9_-]+)+$/
        const isSuilt = reg.test(state.emailVal)
        if (isSuilt) {
          try {
            sendNative(
              'jsCall_callAppService',
              {
                method: 'post',
                url: '/api/rmrb-interact/interact/en/c/subscribe/sure',
                parameters: {
                  deviceId: state.deviceId,
                  email: `${state.emailVal}`,
                  userId: state.userId,
                  aboutUserName: state.aboutUserName
                }
              },
              (res) => {
                const emailSubResponse = typeof res === 'object' ? res : JSON.parse(res)
                const netError = emailSubResponse && emailSubResponse.netError
                const responseMap = typeof emailSubResponse.responseMap === 'object'
                  ? emailSubResponse.responseMap
                  : JSON.parse(emailSubResponse.responseMap)
                const Substatus = responseMap && responseMap.data.status
                if (emailSubResponse) {   // 后端说高频
                  if (netError === '0') {
                    if (Substatus === 0) {
                      // toast('邮箱验证错误')
                      toast('Email verification error')
                      flagSub.value = false
                    } else if (Substatus === 1) {
                      toast('Already submitted')
                      flagSub.value = false
                    } else if (Substatus === 2) {
                      try {
                        sendNative(
                          'jsCall_currentPageOperate',
                          {
                            operateType: '50'
                          }
                        )
                      } catch (e) {}
                      toast('Submission successful')
                      const record = deepCopy(state.details)
                      record.mainChannel = record.channelList ? record.channelList[0] : {}

                      nameClickPoint('mail', {
                        pageId: record.mainChannel.pageId || '',
                        newsType: record.newsType,
                        mail_address: state.emailVal || ''
                      })
                      state.isSub = true

                      state.emailVal = ''
                    } else {
                    }
                  } else {
                    errorResponse()
                    errorBlock('./image/no_net.png', 'Please check your network connection and try again!')
                  }
                } else {
                  toast('An error occurred . Please try again later')
                  flagSub.value = false
                }

              }
            )
          } catch (e) {}
        } else {
          toast('Please enter a valid email address')
          flagSub.value = false
        }
      }

    }
    // taost 提示
    const toast = (str) => {
      try {
        sendNative(
          'jsCall_showGeneralTips',
          {
            tipStyle: '1',
            tipString: str
          }
        )
      } catch (e) {}
    }

    // 获取推荐数据
    const getRecommendData = async () => {
      const channelIds = state.details.channelList
        ? state.details.channelList.map(el => el.channelId)
        : []
      if (window.config.VUE_BASE_NODE === 'dev') {
        const response = await axiosRequest({
          url: 'recommend/en/c/detail',
          methot: 'post',
          appStatus: false,
          environment: state.environment,
          prefix: '/api/rmrb-bff-display-en/',
          headers: state.appHeader,
          showError: false,
          data: {
            returnCount: 3,
            channelIds,
            contentId: state.details.newsId,
            // contentId: 30000005218,
            contentType: 8,
            imei: state.deviceId
          }
        })
        if (response.success) {
          let data = response.data
          data = data.filter(itm => {    // 过滤掉与当前的内容详情项
            return state.details.newsId != itm.newsId
          })
          state.recomList = data
          state.recomList.forEach(el => {
            const record = deepCopy(el)
            record.mainChannel = record.channelList ? record.channelList[0] : {}
            const secondChannel = record.channelList ? record.channelList[1] : {}
            record.secondId = secondChannel ? secondChannel.channelId || '' : ''

            contentListExposure(pointData(record, true))
          })
          suggestedList.value = data.map(item => {
            return {
              shareInfo: {
                shareUrl: item.shareInfo ? item.shareInfo.shareUrl : '',
                shareCoverUrl: item.shareInfo ? item.shareInfo.shareCoverUrl : '',
                shareTitle: item.shareInfo ? item.shareInfo.shareTitle : item.newsTitle,
                shareSummary: item.shareInfo ? item.shareInfo.shareSummary : item.newsSummary || item.newsTitle
              },
              shareUrl: item.shareInfo ? item.shareInfo.shareUrl : '',
              title: item.newsTitle,
              description: item.newsSummary,
              publishArea: item.newsSource,
              cover: item.fullColumnImgUrls
                ? item.fullColumnImgUrls[0]
                  ? item.fullColumnImgUrls[0].url : '' : '',
              ...item,
              publishTime: timeFromNow(dayjs(getChinaTimeUix(item.publishTime))),
            }
          })
        }
      } else {
        try {
          sendNative(
            'jsCall_callAppService',
            {
              method: 'post',
              url: '/api/rmrb-bff-display-en/recommend/en/c/detail',
              parameters: {
                returnCount: 3,
                channelIds,
                contentId: state.details.newsId,
                contentType: 8,
                imei: state.deviceId
              }
            },
            (res) => {
              const recommendResponse = typeof res === 'object' ? res : JSON.parse(res)
              const responseMap = typeof recommendResponse.responseMap === 'object'
                ? recommendResponse.responseMap
                : JSON.parse(recommendResponse.responseMap)
              let recommendData = responseMap && responseMap.data ? responseMap && responseMap.data : []
              recommendData = recommendData.filter(itm => {   // 去除掉当前页面的详情内容，保证推荐列表中不包含当前页面
                return state.details.newsId != itm.newsId
              })
              state.recomList = deepCopy(recommendData)
              state.recomList.forEach(el => {
                const record = deepCopy(el)
                record.mainChannel = record.channelList ? record.channelList[0] : {}
                const secondChannel = record.channelList ? record.channelList[1] : {}
                record.secondId = secondChannel ? secondChannel.channelId || '' : ''

                try {
                  contentListExposure(pointData(record, true))
                } catch (e) {}
              })
              suggestedList.value = recommendData.map(item => {
                return {
                  shareInfo: {
                    shareUrl: item.shareInfo ? item.shareInfo.shareUrl : '',
                    shareCoverUrl: item.shareInfo ? item.shareInfo.shareCoverUrl : '',
                    shareTitle: item.shareInfo ? item.shareInfo.shareTitle : item.newsTitle,
                    shareSummary: item.shareInfo ? item.shareInfo.shareSummary : item.newsSummary || item.newsTitle
                  },
                  shareUrl: item.shareInfo ? item.shareInfo.shareUrl : '',
                  title: item.newsTitle,
                  description: item.newsSummary,
                  publishArea: item.newsSource,
                  cover: item.fullColumnImgUrls
                    ? item.fullColumnImgUrls[0]
                      ? item.fullColumnImgUrls[0].url : '' : '',
                  ...item,
                  publishTime: timeFromNow(dayjs(getChinaTimeUix(item.publishTime))),
                }
              })
            }
          )
        } catch (e) {}
      }
    }

    const errorResponse = () => {
      clearInterval(time.value)
    }

    // 调移动端方法拿用户翻篇的页数
    const getPages = (strategy, callBack) => {
      if (window.config.VUE_BASE_NODE === 'dev') {
        state.nextInit = false
        callBack()
      } else {
        try {
          sendNative(       //  'jsCall_getArticleBrowseNumber',   替换了这个方法
            'jsCall_getArticleDetailBussinessData',
            {
              getArticleBrowseNumber: '1'
            },
            (res) => {
              const resposn = typeof res === 'object' ? res : JSON.parse(res)
              const pageNums = resposn && resposn.articleBrowseNumber
              articNumber.value = pageNums
              if (articNumber.value >= strategy.articleBegin && articNumber.value <= strategy.articleEnd) {
                state.seeEmailSub = true
              } else {
                state.seeEmailSub = false
              }
              state.nextInit = false
              callBack()
            }
          )
        } catch (e) {}
      }
    }

    // 用户订阅状态查询
    const getEmailSubStatus = (callBack) => {
      if (state.firstSubRes) {
        //  1、调用移动端方法，拿到用户翻篇的数量， 2、再与后端返回的两个字段相比， 3、在范围内，入口就展示，否则不展示
        getPages(state.strategy, callBack)
      } else {
        if (window.config.VUE_BASE_NODE === 'dev') {
          callBack()
          state.nextInit = false
        } else {
          try {
            sendNative(
              'jsCall_callAppService',
              {
                method: 'get',
                url: '/api/rmrb-interact/interact/en/c/subscribe/status',
                parameters: {
                  deviceId: state.deviceId,
                  userId: state.userId
                }
              },
              (res) => {
                const SubStatusResponse = typeof res === 'object' ? res : JSON.parse(res)
                const netError = SubStatusResponse.netError
                const responseMap = typeof SubStatusResponse.responseMap === 'object'
                  ? SubStatusResponse.responseMap
                  : JSON.parse(SubStatusResponse.responseMap)
                const Substatus = responseMap && responseMap.data && responseMap.data.status    // 0 未订阅 ， 1 已订阅
                const strategy = responseMap.data.strategy || {}
                state.strategy = deepCopy(strategy)
                if (netError == '0') {
                  if (Substatus == 1) {   // 已订阅 不展示入口
                    state.isSub = true
                    callBack()
                    state.nextInit = false
                  } else {
                    //  1、调用移动端方法，拿到用户翻篇的数量， 2、再与后端返回的两个字段相比， 3、在范围内，入口就展示，否则不展示
                    getPages(strategy, callBack)
                  }
                } else {
                  errorResponse()
                  errorBlock('./image/no_net.png', 'Please check your network connection and try again!')
                }
              }
            )
          } catch (e) {}
        }
      }
    }

    const changeNetworkStatus = () => {
      if (window.config.VUE_BASE_NODE === 'dev') {
        networkStatus.value = window.config.VUE_APP_NETWORK
      } else {
        let objNvt = window.config.VUE_APP_NETWORK ? window.config.VUE_APP_NETWORK : {}
        let lastObjNvt = null
        if (judgTerminal() === 1) {  // 安卓
          lastObjNvt = JSON.parse(objNvt)
        } else {
          lastObjNvt = objNvt
        }
        networkStatus.value = lastObjNvt.networkStatus
      }
    }

    const changeNoticeStatus = () => {
      if (window.config.VUE_BASE_NODE === 'dev') {
      } else {
        try {
          let objEvt = window.config.VUE_APP_LOGIN ? window.config.VUE_APP_LOGIN : ''
          let lastObjEvt = typeof objEvt === 'object' ? objEvt : JSON.parse(objEvt)
          if (lastObjEvt && (lastObjEvt.event == '5' || lastObjEvt.event == '2' || lastObjEvt.event == '4')) {  // 音频播放 或者 离开页面
            audioState.value += 1

          }
        } catch (e) {}
      }
    }

    // 页面加载，取客户端记录是否点击了继续播放按钮的状态值
    const getClickStatus = () => {
      if (window.config.VUE_BASE_NODE === 'dev') {
      } else {
        try {
          sendNative(
            'jsCall_getArticleDetailBussinessData',
            {
              getPlayVideoOnCellularNetworkSwitch: '1'
            },
            (res) => {
              let objNvtSwt = res ? res : {}
              let lastObjNvtSwt = typeof objNvtSwt === 'object' ? objNvtSwt : JSON.parse(objNvtSwt)
              networkSwitch.value = lastObjNvtSwt.playVideoOnCellularNetworkSwitch    // 蜂窝数据播放  1 允许  2 不允许
            }
          )
        } catch (e) {}
      }
    }
    // 页面加载，取客户端记录是否点击了继续播放按钮的状态值
    const getSubHasClose = () => {
      if (window.config.VUE_BASE_NODE === 'dev') {
      } else {
        try {
          sendNative(
            'jsCall_getArticleDetailBussinessData',
            {
              getEmailSubscribeHasClosed: '1'
            },
            (res) => {
              let objSub = res ? res : {}
              let lastObjSub = typeof objSub === 'object' ? objSub : JSON.parse(objSub)
              if (lastObjSub.emailSubscribeHasClosed == 1) { // 邮件订阅关闭  1 关闭  2 未关闭
                state.isSubClose = true
              } else {
                state.isSubClose = false
              }
            }
          )
        } catch (e) {}
      }
    }

    // 未登录时执行，拉起app登录
    const setAppLogin = () => {
      try {
        sendNative(
          'jsCall_appInnerLinkMethod',
          {
            appInnerLink: 'peopledailyen://rmrb.app/openwith?contentType=login&skipType=2'
          },
          (res) => {}
        )
      } catch (e) {}
    }
    // 监听从登录页面回来，拿到移动端给的状态值，并做投票状态的刷新
    const checkAppLoginStatu = () => {
      wheelFun(state.voteId, state.details.newsId)
    }
    const wheelFun = (vid, nid) => {  // 回调函数的形式 做轮巡
      loginTime.value = setInterval(() => {
        try {
          let objEvt = window.config.VUE_APP_LOGIN ? window.config.VUE_APP_LOGIN : ''
          let lastObjEvt = typeof objEvt === 'object' ? objEvt : JSON.parse(objEvt)
          if (lastObjEvt && lastObjEvt.event == '1') {   // 由登录页面进到了主页面
            clearInterval(loginTime.value)
            refreshVotes(nid, 0)
            voteStatus(vid)
          }
        } catch (e) {}
      }, 20)
    }
    // 获取用户登录状态
    const getUserLoginStatus = (callback) => {
      try {
        sendNative(
          'jsCall_getAppLoginAuthInfo',
          {},
          (res) => {
            const loginStatusResponse = typeof res === 'object' ? res : JSON.parse(res)
            state.isLogined = loginStatusResponse && loginStatusResponse.isLogined
            if (callback !== undefined) {
              callback(state.isLogined)
            }
          }
        )
      } catch (e) {

      }
    }

    // 投票按钮
    const goVote = (voteId, optionId, index) => {
      window.config.VUE_APP_LOGIN = ''    // 由于页面加载就会给 '1' ,所以点投票先清空，否则会影响后面的轮巡判断
      getUserLoginStatus((loginId) => {
        if (loginId == 0) {     // 1 已登录 0 未登录
          state.voteId = voteId
          setAppLogin()
          checkAppLoginStatu()
          return
        } else {    // 已登录 直接去投票
          if (state.Doing) {
            return
          } else {
            state.Doing = true
            setVote(voteId, optionId, index)
          }

        }
      })
    }
    // 用户投票
    const setVote = async (vID, oID, index) => {
      if (window.config.VUE_BASE_NODE === 'dev') {
        const response = await axiosRequest({
          url: '/contact/en/c/vote/submit',
          methot: 'post',
          appStatus: false,
          environment: state.environment,
          prefix: '/api/rmrb-contact',
          data: { 'voteId': `${vID}`, 'optionId': oID },
          headers: state.appHeader,
          showError: false
        })
        if (response.success) {
          // 刷新投票状态
          voteStatus(state.details.voteInfo.voteId, index)
          refreshVotes({}, 30000001196)
          state.Doing = false
        }
      } else {
        try {
          sendNative(
            'jsCall_callAppService',
            {
              method: 'post',
              url: '/api/rmrb-contact/contact/en/c/vote/submit',
              parameters: { 'voteId': `${vID}`, 'optionId': oID }
            },
            (res) => {
              const vtSubmitResponse = typeof res === 'object' ? res : JSON.parse(res)
              const netError = vtSubmitResponse && vtSubmitResponse.netError
              const vtSubmitResponseMap = typeof vtSubmitResponse.responseMap === 'object'
                ? vtSubmitResponse.responseMap
                : JSON.parse(vtSubmitResponse.responseMap)
              if (netError == 0) {
                try {
                  const code = vtSubmitResponseMap.code
                  const newId = state.details && state.details.newsId
                  if ([ 200, '0' ].includes(code)) {
                    // 刷新投票状态
                    refreshVotes(newId, 0)
                    //voteStatus(state.details.voteInfo.voteId , index)
                    toast('Success')
                    const record = deepCopy(state.details)
                    record.mainChannel = record.channelList ? record.channelList[0] : {}
                    const voteRecord = optionList.value.find(el => el.optionId == oID)
                      ? optionList.value.find(el => el.optionId == oID) : {}
                    nameClickPoint('vote', {
                      pageId: record.mainChannel.pageId || '',
                      newsType: record.newsType,
                      vote_content: voteRecord.summary || ''
                    })
                    voteStatus(vID, index)            // 投票前  投票后

                    state.Doing = false
                  } else {
                    toast(vtSubmitResponseMap.message)
                  }
                } catch (e) {}
              } else {
                errorResponse()
                errorBlock('./image/no_net.png', 'Please check your network connection and try again!')
              }
            }
          )
        } catch (e) {}
      }
    }

    // 展示所有选项
    const showAllSelect = () => {   // 投票前
      try {
        canSeeBtnOne.value = false
      } catch (e) {}
    }
    const showAllSelect2 = () => {    // 投票后
      try {
        canSeeBtnTwo.value = false
      } catch (e) {}
    }

    // 刷新投票状态
    const refreshVotes = async (eq, id) => {
      if (window.config.VUE_BASE_NODE === 'dev') {
        const response = await axiosRequest({
          url: '/content/en/c/content/detail',
          methot: 'post',
          appStatus: false,
          environment: state.environment,
          prefix: '/api/rmrb-bff-display-en',
          data: { contentIds: [ id ] },
          headers: state.appHeader
        })
        if (response.success) {
          if (response.data) {
            const details = response.data.length > 0 ? response.data[0] : {}
            if (details.voteInfo) {
              state.details.voteInfo = details.voteInfo
            } else {
              details.voteInfo = {}
            }
          } else {
            errorResponse()
          }
        } else {
          errorResponse()
        }
      } else {
        try {
          sendNative(
            'jsCall_callAppService',
            {
              method: 'post',
              url: '/api/rmrb-bff-display-en/content/en/c/content/detail',
              parameters: { contentIds: [ eq ] }
            },
            (res) => {
              const refResponse = typeof res === 'object' ? res : JSON.parse(res)
              const netError = refResponse.netError
              if (netError == 0) {
                try {
                  const refResponseMap = typeof refResponse.responseMap === 'object'
                    ? refResponse.responseMap
                    : JSON.parse(refResponse.responseMap)
                  const code = refResponseMap.code
                  const data = refResponseMap.data[0]
                  if ([ 200, '0' ].includes(code) && data) {
                    if (Object.keys(data).length > 0) {
                      state.details.voteInfo = data.voteInfo      //  决定页面展示 PK  还是多选一
                    }
                  } else {
                  }
                } catch (e) {

                }
              } else {
                errorResponse()
                errorBlock('./image/no_net.png', 'Please check your network connection and try again!')
              }
            }
          )
        } catch (e) {

        }
      }
    }

    // 用户投票状态查询
    const voteStatus = async (vId, index) => {
      if (window.config.VUE_BASE_NODE === 'dev') {
        const response = await axiosRequest({
          url: '/contact/en/c/vote/queryStatus',
          methot: 'get',
          appStatus: false,
          environment: state.environment,
          prefix: '/api/rmrb-contact',
          params: { voteId: vId },
          headers: state.appHeader,
          showError: false
        })
        if (response.success) {
          if (response.data) {
            state.voteState.status = response.data.status    //  展示投票后的样式
            state.voteState.optionId = response.data.optionId
            if (state.details.voteInfo.style === 1) {        //  展示对 √
              state.bcIndex = index
            } else {
              state.curIndex = index
            }
          }
        }
      } else {
        try {
          sendNative(
            'jsCall_callAppService',
            {
              method: 'get',
              url: '/api/rmrb-contact/contact/en/c/vote/queryStatus',
              parameters: { voteId: vId }
            },
            (res) => {
              const voteStatusResponse = typeof res === 'object' ? res : JSON.parse(res)
              const netError = voteStatusResponse.netError
              const vtStatusResponseMap = typeof voteStatusResponse.responseMap === 'object'
                ? voteStatusResponse.responseMap
                : JSON.parse(voteStatusResponse.responseMap)
              if (netError == 0) {
                try {
                  const code = vtStatusResponseMap.code
                  const data = vtStatusResponseMap.data
                  if ([ 200, '0' ].includes(code) && data) {
                    if (Object.keys(data).length > 0) {
                      try {
                        state.voteState.status = data.status      //  决定是投票前0 还是 投票后1
                        state.voteState.optionId = data.optionId      // 返回的是 被投票项的 optionId ，没投就是 ''
                      } catch (e) {}
                      if (state.details.voteInfo.style === 1) {        //  展示对 √
                        state.bcIndex = index
                      } else {
                        state.curIndex = index
                      }
                    }
                  } else {
                    toast(vtStatusResponseMap.message)
                  }
                } catch (e) {}
              } else {
                errorResponse()
                errorBlock('./image/no_net.png', 'Please check your network connection and try again!')
              }
            }
          )
        } catch (e) {}
      }
    }

    //  页面加载 内容详情数据
    const initData = async (res, id) => {
      document.querySelector('.content-block .content').classList.remove('active')
      document.querySelector('.content-block .content-loading').classList.add('active')

      if (window.config.VUE_BASE_NODE === 'dev') {
        const response = await axiosRequest({
          url: '/content/en/c/content/detail',
          methot: 'post',
          appStatus: false,
          environment: state.environment,
          prefix: '/api/rmrb-bff-display-en',
          data: { contentIds: [ id ] },
          headers: state.appHeader
        })
        if (response.success) {
          state.recomList = []
          if (response.data) {
            const details = response.data.length > 0 ? response.data[0] : {}

            handleArticle(details)

            if (Object.keys(details).length) {
              nextData(details)
            }
          } else {
            errorResponse()
            appBlock(true)
            mobileApp(true)
            errorBlock('./image/content_fail.png', 'An error occurred. Please try again later')
          }
        } else {
          errorResponse()
          appBlock(true)
          mobileApp(true)
          errorBlock('./image/content_fail.png', 'An error occurred. Please try again later')
        }
      } else {
        if ([ 200, '0' ].includes(res.code) > 0) {
          if (res.data) {
            state.recomList = []
            const details = res.data.length > 0 ? res.data[0] : {}
            state.firstObject = deepCopy(details)
            // 获取用户登录状态
            try {
              sendNative(
                'jsCall_getAppLoginAuthInfo',
                {},
                (res) => {
                  const loginStatusResponse = typeof res === 'object' ? res : JSON.parse(res)
                  state.isLogined = loginStatusResponse && loginStatusResponse.isLogined
                  state.aboutUserName = loginStatusResponse && loginStatusResponse.userName
                  handleArticle(details)

                  if (Object.keys(details).length) {
                    nextData(details)
                  }
                }
              )
            } catch (e) {

            }
          } else {
            errorResponse()
            // errorBlock('./image/error.svg', '内容获取失败')
            errorBlock('./image/content_fail.png', 'An error occurred. Please try again later')
          }
        } else {
          errorResponse()
          // errorBlock('./image/error.svg', '内容获取失败')
          errorBlock('./image/content_fail.png', 'An error occurred. Please try again later')
        }
      }
    }
    // 点击next后 从nextArticleData拿数据
    const handleNextArticle = () => {
      refreshEditorStr()
      state.nextInit = true
      state.showShare = false
      state.details = {}
      state.details.endTimePoint = ''
      state.details.options = []
      state.originDataSource = {}
      const details = nextArticleData.value.length > 0 ? deepCopy(nextArticleData.value[0]) : {}
      nextArticleData.value = nextArticleData.value.filter(el => el.newsId !== details.newsId)  // 取一条就过滤去除一条
      handleArticle(details)

      if (nextArticleData.value.length === 0 && Object.keys(details).length) {
        if (state.sourcePage == '1' || state.sourcePage == '2') {
          if (!state.hasNext) {
            state.nextNodata = true
            return
          }
        }
        state.nextLoading = true
        state.nextPageInfo.pageNum += 1
        nextData(details)
      }
    }
    // 定义 next 请求数据的方法
    const nextData = async (details) => {
      const channelIds = details.channelList

      if (window.config.VUE_BASE_NODE === 'dev') {
        const response = await axiosRequest({
          url: state.isRecommond
            ? '/recommend/en/c/detail'
            : state.sourcePage == '1' || state.sourcePage == '2'
              ? '/content/en/c/interactNexts'
              : '/content/en/c/nextContent',
          methot: state.isRecommond ? 'post' : 'get',
          showError: false,
          appStatus: false,
          environment: state.environment,
          prefix: '/api/rmrb-bff-display-en',
          params: state.isRecommond
            ? {} : state.sourcePage == '1' || state.sourcePage == '2' ? {
              type: state.sourcePage,
              contentId: state.nextPageInfo.pageNum > 1 ? null : state.firstObject.newsId,
              contentType: state.firstObject.newsType,
              pageSize: state.nextPageInfo.pageSize,
              pageNum: state.nextPageInfo.pageNum,
              requestTime: dayjs().valueOf(),
              ...state.nextParams
            } : {
              currentContentId: details.newsId,
              currentContentType: details.newsType,
              requestNum: 10,
              refreshTime: dayjs().valueOf(),
              ...state.nextParams
            },
          data: state.isRecommond ? {
            returnCount: 10,
            channelIds,
            contentId: details.newsId,
            contentType: 8,
            imei: state.deviceId
          } : {

          },
          headers: state.appHeader
        })
        if (response.success) {
          if (state.isRecommond) {
            let data = deepCopy(response.data)
            if (data && data.length > 0) {
              data = data.filter(itm => {    // 过滤掉与当前的内容详情项
                return details.newsId != itm.newsId
              })
              state.nextNodata = false
              nextArticleData.value = [ ...nextArticleData.value, ...deepCopy(data) ]
            } else {
              state.nextNodata = true
            }
            state.nextLoading = false
          } else if (state.sourcePage == '1' || state.sourcePage == '2') {
            if (response.data) {
              const list = response.data.list
              if (list.length > 0) {
                nextArticleData.value = [ ...nextArticleData.value, ...deepCopy(list) ]

                nextArticleData.value = list.filter(el => el.newsId !== state.details.newsId)

                if (nextArticleData.value.length > 0) {
                  // state.hasNext = response.data.hasNext !== 0
                  state.nextNodata = false
                } else {
                  state.nextNodata = true
                }
              } else {
                state.nextNodata = true
              }
            } else {
              state.nextNodata = true
            }
            state.nextLoading = false
          } else {
            let data = deepCopy(response.data)
            if (data && data.length > 0) {
              nextArticleData.value = [ ...nextArticleData.value, ...deepCopy(data) ]
            } else {
              state.nextNodata = true
            }
            state.nextLoading = false
          }
        }
      } else {
        try {
          // getEmailSubStatus()   // 查询“邮件订阅”状态
          sendNative(
            'jsCall_callAppService',
            {
              method: state.isRecommond ? 'POST' : 'GET',
              url: state.isRecommond
                ? '/api/rmrb-bff-display-en/recommend/en/c/detail'
                : state.sourcePage == '1' || state.sourcePage == '2'
                  ? '/api/rmrb-bff-display-en/content/en/c/interactNexts'
                  : '/api/rmrb-bff-display-en/content/en/c/nextContent',
              parameters: state.isRecommond
                ? {
                  returnCount: 10,
                  channelIds,
                  contentId: details.newsId,
                  contentType: 8,
                  imei: state.deviceId
                } : state.sourcePage == '1' || state.sourcePage == '2'
                  ? {
                    type: state.sourcePage,
                    contentId: state.nextPageInfo.pageNum > 1 ? null : state.firstObject.newsId,
                    contentType: state.firstObject.newsType,
                    pageSize: state.nextPageInfo.pageSize,
                    pageNum: state.nextPageInfo.pageNum,
                    requestTime: dayjs().valueOf(),
                    ...state.nextParams
                  } : {
                    currentContentId: details.newsId,
                    currentContentType: details.newsType,
                    requestNum: 10,
                    refreshTime: dayjs().valueOf(),
                    ...state.nextParams
                  }
            },
            (res) => {
              const response = typeof res === 'object' ? res : JSON.parse(res)
              const netError = response.netError
              if (netError == 0) {
                try {
                  const responseMap = typeof response.responseMap === 'object' ? response.responseMap : JSON.parse(
                    response.responseMap)
                  const code = responseMap.code
                  let data = responseMap.data
                  if ([ 200, '0' ].includes(code) && data) {
                    if (state.isRecommond) {
                      if (data.length > 0) {
                        data = data.filter(itm => {    // 过滤掉与当前的内容详情项
                          return details.newsId != itm.newsId
                        })

                        nextArticleData.value = [ ...nextArticleData.value, ...deepCopy(data) ]
                        state.nextNodata = false
                      } else {
                        state.nextNodata = true
                      }
                      state.nextLoading = false
                    } else if (state.sourcePage == '1' || state.sourcePage == '2') {
                      const list = data.list || []
                      if (list && list.length > 0) {
                        nextArticleData.value = list.filter(el => el.newsId !== state.details.newsId)

                        if (nextArticleData.value.length > 0) {
                          state.nextNodata = false
                        } else {
                          state.nextNodata = true
                        }
                      } else {
                        state.nextNodata = true
                      }
                      state.nextLoading = false
                    } else {
                      if (data.length > 0) {
                        nextArticleData.value = [ ...nextArticleData.value, ...deepCopy(data) ]
                        state.nextNodata = false
                      } else {
                        state.nextNodata = true
                      }
                      state.nextLoading = false
                    }
                  } else {
                    state.nextLoading = false
                    state.nextNodata = true
                  }
                } catch (e) {}
              } else {
                errorResponse()
                errorBlock('./image/no_net.png', 'Please check your network connection and try again!')
              }
            }
          )
        } catch (e) {}
      }
    }

    const handleArticle = (details) => {
      document.querySelector('.content-block .content').classList.remove('active')
      document.querySelector('.content-block .content-loading').classList.add('active')

      if (Object.keys(details).length === 0) {
        errorResponse()
        // errorBlock('./image/error.svg', '暂无内容')
        errorBlock('./image/content_fail.png', 'An error occurred. Please try again later')
        return
      }
      state.showShare = true
      state.nextClick = false
      state.details = deepCopy(details)
      state.originDataSource = deepCopy(details)
      state.details.endTimePoint = ''
      state.details.options = []
      if (window.config.VUE_BASE_NODE === 'dev') {
        initApp(details)
      } else {
        try {
          sendParams(() => initApp(details))
        } catch (e) {
        }
      }
    }

    const handleVoteList = () => {
      const tots = state.details.voteInfo && state.details.voteInfo.options ? state.details.voteInfo.options.reduce((
        x,
        i
      ) => {
        return x + i.totalVotes
      }, 0) : 0
      let datsArr = state.details.voteInfo && state.details.voteInfo.options
        ? state.details.voteInfo.options.map(ep => {
          ep.votesBf = tots > 0 ? parseInt(ep.totalVotes / tots * 100) : 0
          return ep
        })
        : []
      if (tots != 0) {  // 这里面的作用，让投票结果百分数之和恰好为 100%
        let bfTols = 0
        let bfMax = datsArr[0].votesBf
        let index = 0
        let bfgDiff = 0
        for (let i = 0; i < datsArr.length; i++) {
          bfTols += datsArr[i].votesBf
          if (bfMax < datsArr[i].votesBf) {
            bfMax = datsArr[i].votesBf
            index = i
          }
        }
        bfgDiff = bfTols - 100
        if (bfgDiff > 0) {
          datsArr[index] = bfMax - bfgDiff
        } else if (bfgDiff < 0) {
          datsArr[index] = bfMax + Math.abs(bfgDiff)
        } else {}
      } else {
        if (datsArr.length > 0 && state.details.voteInfo && state.details.voteInfo.style === 1) {
          if (datsArr[0].votesBf === 0 && datsArr[1].votesBf === 0) {
            datsArr = datsArr.map(item => {
              return {
                ...item,
                votesBf: 50
              }
            })
          }
        }
      }

      datsArr = deepCopy(datsArr).map((item, index) => {
        const voteWidth = document.querySelector('.vote .title')
          ? document.querySelector('.vote .title').getBoundingClientRect().width
          : 0
        const oneWidth = state.details.voteInfo.style == 1 && index === 0 ? (item.votesBf == 0
          ? 8
          : datsArr[index + 1].votesBf == 0 ? 92 : item.votesBf) : 0
        const twoWidth = state.details.voteInfo.style == 1 && index === 1 ? (item.votesBf == 0
          ? 8
          : datsArr[index - 1].votesBf == 0 ? 92 : item.votesBf) : 0
        return {
          ...item,
          oneStyle: {
            width: `${oneWidth}%`,
            clipPath: `polygon(0 0, 100% 0, ${voteWidth * (oneWidth / 100) - 4}px 100%, 0 100%)`
          },
          twoStyle: {
            width: `${twoWidth}%`,
            clipPath: `polygon(4px 0, 100% 0, 100% 100%, 0 100%)`
          }
        }
      })

      optionList.value = deepCopy(datsArr)
    }

    const initApp = (data) => {
      getEmailSubStatus(() => {
        state.details.options = []
        getRecommendData()
        getSubHasClose()
        if (data.voteInfo) {
          state.details.voteInfo = data.voteInfo
          state.details.endTimePoint = data.voteInfo.endTime === '' || !data.voteInfo.endTime
            ? false
            : (data.voteInfo.endTime - Date.now()) > 0
              ? dayjs(Number(data.voteInfo.endTime)).format('HH:mm, MMM DD, YYYY')
              : 'Closed'
          state.details.options = data.voteInfo.options ? Array.isArray(data.voteInfo.options) ? data.voteInfo.options : [] : []
          state.details.yes = data.voteInfo.options && data.voteInfo.options[0]
          state.details.no = data.voteInfo.options && data.voteInfo.options[1]

        } else {
          data.voteInfo = {}
        }
        if (data.authorList && data.authorList.length > 0) {
          state.details.author = data.authorList.map(el => el.authorName).join('|').split('|').filter(el => el)
          state.details.webAuthorList = data.authorList.map(el => el.authorName).join()
        }
        state.details.publishTime = data.publishTime ? dayjs(getChinaTimeUix(data.publishTime)).format('HH:mm, MMM DD, YYYY') : ''
        subjectList.value = data.subjectList ? data.subjectList.map(el => el.name).filter(el => el) : []
        channelList.value = data.channelList ? data.channelList.map(el => el.channelName).filter(el => el) : []
        if (data.photoList && data.photoList.length) {
          state.details.imgUrl = data.photoList[0].picPath
          state.details.imgDcs = data.photoList[0].picDesc
        }
        // 监听页面返回时机，刷新投票状态
        // listenReturnPage(data.voteInfo && data.voteInfo.voteId , state.details && state.details.newsId)
        // 调用用户投票状态的方法
        if (state.isLogined == 1) {
          if (data.voteInfo && data.voteInfo.voteId) {
            voteStatus(data.voteInfo.voteId)
          }
        }
        const record = deepCopy(state.details)
        record.mainChannel = record.channelList ? record.channelList[0] : {}
        const secondChannel = record.channelList ? record.channelList[1] : {}
        record.secondId = secondChannel ? secondChannel.channelId || '' : ''
        try {
          channelExposure(pointData(record, !!record.traceId))
        } catch (e) {}
        // channelExposure()
        // getPages(state.strategy)    // 查询总浏览的页数
        getClickStatus()
        appBlock(true)
        mobileApp(true)
        setTimeout(initEditorStr, 300)
        setTimeout(() => {
          handleVoteList()
        })
      })   // 判断是否订阅，有不展示入口，没有取获取浏览的总次数并进行比较

    }

    const sendParams = (callback) => {
      sendNative(
        'jsCall_receiveH5Data',
        { dataSource: '1', dataJson: JSON.stringify(state.originDataSource) },
        callback
      )
    }
    // 推荐每项的点击事件
    const recommondItemClick = (index) => {
      if (window.config.VUE_BASE_NODE === 'dev') {
        state.showShare = false
        refreshEditorStr()
        state.details = {}
        state.originDataSource = {}

        initData({}, state.recomList[index].newsId)
        state.isRecommond = true
      } else {
        if (recommondClickActive.value == true) {
          return
        }

        recommondClickActive.value = true

        const record = deepCopy(state.recomList[index] || {})

        record.mainChannel = record.channelList ? record.channelList[0] : {}
        const secondChannel = record.channelList ? record.channelList[1] : {}
        record.secondId = secondChannel ? secondChannel.channelId || '' : ''

        try {
          contentClick(pointData(record, true))
        } catch (e) {}

        sendNative(
          'jsCall_receiveH5Data',
          {
            dataSource: '2',
            dataJson: JSON.stringify(state.recomList[index])
          },
          () => {
            recommondClickActive.value = false
          }
        )
      }
    }

    const openShare = (sharePlatform, record = {}, recommond) => {
      const shareInfo = record.shareInfo || state.details.shareInfo
      if (shareInfo && shareInfo.shareUrl) {
        const details = deepCopy(record.newsId ? record : state.details)
        details.mainChannel = details.channelList ? details.channelList[0] : {}
        const secondChannel = details.channelList ? details.channelList[1] : {}
        details.secondId = secondChannel ? secondChannel.channelId || '' : ''
        try {
          shareClickPoint(pointData(details), recommond ? true : !!record.traceId)
        } catch (e) {}

        if (sharePlatform != '7') {
          shareTypePoint({
            ...pointData(details),
            share_type: sharePlatform == '1' ? 'facebook' : sharePlatform == '2' ? 'twitter' : sharePlatform == '3' ? 'wechat' : sharePlatform == '5' ? 'sina' : ''
          }, recommond ? true : !!record.traceId)
        }

        try {
          sendNative('jsCall_openAppShare', {
            type: '2',
            isShowShare: 0,
            title: shareInfo.shareTitle,
            description: shareInfo.shareSummary,
            webpageUrl: shareInfo.shareUrl,
            imageUrl: shareInfo.shareCoverUrl,
            contentId: record.newsId || state.details.newsId,
            sharePlatform
          }, () => {})
        } catch (e) {
        }
      }
    }

    watch(() => state.nextLoading, (val) => {
      if (!val && state.nextClick) {
        if (nextArticleData.value.length) {
          const details = nextArticleData.value.length > 0 ? deepCopy(nextArticleData.value[0]) : {}
          nextArticleData.value = nextArticleData.value.filter(el => el.newsId !== details.newsId)
          handleArticle(details)
        } else {
          handleArticle({})
        }
      }
    }, { deep: true })

    const next = () => {
      if (state.nextLoading) {
        state.showShare = false
        state.nextClick = true
        refreshEditorStr()
        state.details = {}
        state.originDataSource = {}
        return
      }
      if (state.nextInit) {
        return
      }
      handleNextArticle()
    }

    return {
      ...toRefs(state),
      canSeeBtnOne,
      canSeeBtnTwo,
      showAction,
      subjectList,
      channelList,
      suggestedList,
      optionList,
      inptClick,
      emailSubmit,
      closeEmailSub,
      recommondItemClick,
      goVote,
      showAllSelect,
      showAllSelect2,
      next,
      openShare,
      sendParams,
      changeNetworkStatus,
      changeNoticeStatus
    }
  }
})

app.mount('#app')
