const successCode = [ 200, '0' ]

async function request(config) {
  const {
    methot = 'get',
    url,
    timeOut = 500,
    prefix,
    appStatus = true,
    showError = true,
    environment = 'sit',
    token,
    data = {},
    params = {},
    showToken = true
  } = config
  return new Promise((resolve) => {
    if (url.includes('/mock')) {
      setTimeout(() => {
        const code = '0'

        if (appStatus) {
          appBlock(true)
        }

        if (!successCode.includes(code) && showError) {
          errorBlock('./image/content_fail.png', 'An error occurred. Please try again later')
        }

        const data = mockList.find(el => el.url === url).data

        resolve({
          success: successCode.includes(code),
          data: successCode.includes(code) ? data ? deepCopy(data) : null : null
        })
      }, timeOut)
      return
    }
    const VUE_BASE_API = window.config.VUE_BASE_API[environment]

    let responseUrl = VUE_BASE_API + prefix + url
    if (methot.toLowerCase() === 'get' && Object.keys(delectEmptyObj(params)).length) {
      responseUrl = `${responseUrl}?${tansParams(params)}`
    }
    const ajaxConfig = {
      type: methot,
      url: responseUrl,
      dataType: 'json',
      async: false,
      headers: {
        ...config.headers
      }
    }

    if (data && Object.keys(data).length) ajaxConfig.data = JSON.stringify(data)

    if (showToken && (token || getQueryVariable('token'))) {
      ajaxConfig.headers.token = token || getQueryVariable('token')
    }

    $.ajax({
      contentType: 'application/json',
      timeout: 1,
      ...ajaxConfig,
      success: (res) => {
        if (appStatus) {
          appBlock(true)
        }

        if (!successCode.includes(res.code) && showError) {
          if (navigator.onLine) {
            errorBlock('./image/no_net.png', 'No collection')
          } else {
            errorBlock('./image/no_net.png', 'Please check your network connection and try again!')
          }
        }

        resolve({
          success: successCode.includes(res.code),
          data: successCode.includes(res.code) ? res.data : res
        })
      },
      error: (_, status) => {
        if (status.includes('timeout')) {
          errorBlock('./image/no_net.png', 'Please check your network connection and try again!')
        }else if (navigator.onLine) {
          // errorBlock('./image/error.svg', '内容获取失败')
          errorBlock('./image/content_fail.png', 'An error occurred. Please try again later')
        } else {
          errorBlock('./image/no_net.png', 'Please check your network connection and try again!')
        }
        if (showError) {
          resolve({
            success: false
          })
        }
      }
    })
  })
}

async function fetchUrl(config) {
  const {
    methot,
    url,
    timeOut = 500,
    prefix,
    appStatus = true,
    showError = true,
    environment = 'sit',
    data = {},
    params = {}
  } = config

  if (url.includes('/mock')) {
    setTimeout(() => {
      const code = '0'

      if (appStatus) {
        appBlock(true)
      }

      if (!successCode.includes(code) && showError) {
        // errorBlock('./image/error.svg', '内容获取失败')
        errorBlock('./image/content_fail.png', 'An error occurred. Please try again later')
      }

      const data = mockList.find(el => el.url === url).data

      resolve({
        success: successCode.includes(code),
        data: successCode.includes(code) ? data ? deepCopy(data) : null : null
      })
    }, timeOut)
    return
  }

  const VUE_BASE_API = window.config.VUE_BASE_API[environment]

  let responseUrl = VUE_BASE_API + prefix + url
  if (methot.toLowerCase() === 'get' && Object.keys(delectEmptyObj(params)).length) {
    responseUrl = `${responseUrl}?${tansParams(params)}`
  }
  const ajaxConfig = {
    method: methot,
    headers: {
      ...config.headers
    }
  }
  if (data && Object.keys(data).length) ajaxConfig.body = JSON.stringify(data)

  return new Promise((resolve) => {
    fetch(responseUrl, ajaxConfig).then(res => res.json()).then(res => {
      if (appStatus) {
        appBlock(true)
      }

      if (!successCode.includes(res.code) && showError) {
        // errorBlock('./image/error.svg', '内容获取失败')
        errorBlock('./image/content_fail.png', 'An error occurred. Please try again later')
      }

      resolve({
        success: successCode.includes(res.code),
        data: successCode.includes(res.code) ? res.data : res
      })
    }).catch(err => {
      console.log(err)
      if (showError) {
        resolve({
          success: false
        })
      }
    })
  })


}

async function axiosRequest(config) {
  const {
    methot = 'get',
    url,
    timeOut = 500,
    prefix,
    appStatus = true,
    showError = true,
    environment = 'sit',
    data = {},
    params = {}
  } = config

  return new Promise((resolve) => {
    if (url.includes('/mock')) {
      setTimeout(() => {
        const code = '0'

        if (appStatus) {
          appBlock(true)
          mobileApp(true)
        }

        if (!successCode.includes(code) && showError) {
          // errorBlock('./image/error.svg', '内容获取失败')
          errorBlock('./image/content_fail.png', 'An error occurred. Please try again later')
        }

        const data = mockList.find(el => el.url === url).data

        resolve({
          success: successCode.includes(code),
          data: successCode.includes(code) ? data ? deepCopy(data) : null : null
        })
      }, timeOut)
      return
    }

    const VUE_BASE_API = window.config.VUE_BASE_API[environment]

    let responseUrl = VUE_BASE_API + prefix + url
    if (methot.toLowerCase() === 'get' && Object.keys(delectEmptyObj(params)).length) {
      responseUrl = `${responseUrl}?${tansParams(params)}`
    }
    const ajaxConfig = {
      method: methot,
      url: responseUrl,
      timeout: 10000,
      headers: {
        ...config.headers
      }
    }

    if (data && Object.keys(data).length) ajaxConfig.data = data

    axios.request(ajaxConfig).then(res => {
      if (appStatus) {
        appBlock(true)
      }

      const { data } = res

      if (!successCode.includes(data.code) && showError) {
        if (navigator.onLine) {
          // errorBlock('./image/error.svg', '内容获取失败')
          errorBlock('./image/content_fail.png', 'An error occurred. Please try again later')
        } else {
          errorBlock('./image/no_net.png', 'Please check your network connection and try again!')
        }
      }

      resolve({
        success: successCode.includes(data.code),
        data: successCode.includes(data.code) ? data.data : data
      })
    }).catch(err => {
      if (showError) {
        if (err.message.includes('timeout')) {
          errorBlock('./image/no_net.png', 'Please check your network connection and try again!')
        }else if (navigator.onLine) {
          // errorBlock('./image/error.svg', '内容获取失败')
          errorBlock('./image/content_fail.png', 'An error occurred. Please try again later')
        } else {
          errorBlock('./image/no_net.png', 'Please check your network connection and try again!')
        }
      }

      resolve({
        success: false
      })
    })
  })
}
